/*
    DisplayCustomers.prg
    Author ...: Ken Mayer
    Date .....: May, 2004
    Notes:
       Display the Data:
       This code is designed to give a listing of the customer data
       in "name" sequence, allowing us to display part of the customer
       data in a web page for the end-user. The sales representatives
       can then click on a row (name, customer number ...) and 
       view the data. 
    Calls:       EditCustomer.dbw
                 DeleteCustomer.dbw
    Called from: index.htm

    Purpose: This is a demonstration of code using dBASE to create
             web applications, created for dBCon 2004. This code
             may be used, modified as needed, etc. for your own
             application, but please give credit where credit is
             due.
*/

// This "included" program handles the initialization of the
// CGI object, the setup of the data, and also handles the
// HTML header and the page title tags, initialization of
// oCGI.cOutString ...:
#INCLUDE <GSCustomerStartCode.prg>

// From here we start the code to display the customer data.
// The setup code above sets the index to the LastFirstName index
// tag, which is perfect for our needs. We will stream out
// each of the customers showing the customer number, first/last
// names, city and postal code. The customer number will have
// a link to the 'edit' screen, which will allow the sales rep
// to view/edit all of the customer data for that individual
// customer.
try
   // First some really basic stuff (center, some title stuff, 
   // end/center):
   oCGI.cOutString +=  [<center><font size="+2">Customer Data</font><br>] 
   oCGI.cOutString +=  [Date: ]+date()+[</center>] 
   oCGI.cOutString +=  [<p>] 

   // ------------------------------------------------
   // now we get to the real heart of the matter ...
   // ------------------------------------------------
   // start the table:
   oCGI.cOutString +=  [<center><table border="1">] 
   //
   // Stream out some headings for the columns:
   oCGI.cOutString +=  [<tr valign="bottom">] 
   oCGI.cOutString +=  [<th>Action</th>]
   oCGI.cOutString +=  [<th>Customer<br>Number</th>] 
   oCGI.cOutString +=  [<th>Customer<br>Name</th>] 
   oCGI.cOutString +=  [<th>City</th>] 
   oCGI.cOutString +=  [<th>Postal<br>Code</th>] 
   oCGI.cOutString +=  [</tr>] 

   // Move to the first row in the rowset:
   rCustomer.first()

   // loop through the table, outputting the data we need:
   do while not rCustomer.endOfSet

      // for each row of a table, we need a <TR> tag -- "Table Row":
      oCGI.cOutString +=  [<tr>] 
      
      // this is where the real work begins -- we have to output
      // individual fields, and in the case of the customer number,
      // we're adding an anchor tag, to allow the user to call
      // the dBL program to view/edit the individual row.

      // Edit/Delete columns-- note that we're using the .dBW file
      // extension, rather than .exe -- this is to allow us
      // to use our own extension that no one else uses (for
      // reference, it means "dBASE Web application") -- details
      // on setting this up are in the online help -- topic
      // is "Web Application" and then "mapping", among other
      // places:
      oCGI.cOutString +=  [<td>] 
      oCGI.cOutString +=  [<a href="EditCustomer.dbw?CustomerNum=]+;
                         fCustomer["CustomerNum"].value+[">]+;
                         "edit"+;
                         [</a>] 
      // some blank space:
      oCGI.cOutString += "&nbsp;&nbsp;&nbsp;"
      // delete ...
      oCGI.cOutString +=  [<a href="DeleteCustomer.dbw?CustomerNum=]+;
                         fCustomer["CustomerNum"].value+[">]+;
                         "delete"+;
                         [</a>] 
      oCGI.cOutString +=  [</td>] 

      // Customer Number: 
      oCGI.cOutString +=  [<td>] 
      oCGI.cOutString +=  fCustomer["CustomerNum"].value
      oCGI.cOutString +=  [</td>] 

      // Customer Name:
      cName = fCustomer["FirstName"].value.rightTrim()+" "+;
              fCustomer["LastName"].value.rightTrim()
      oCGI.cOutString +=  [<td>] 
      oCGI.cOutString +=  cName 
      oCGI.cOutString +=  [</td>] 

      // City:
      oCGI.cOutString +=  [<td>] 
      oCGI.cOutString +=  fCustomer["City"].value 
      oCGI.cOutString +=  [</td>] 

      // Postal Code:
      oCGI.cOutString +=  [<td>] 
      oCGI.cOutString +=  fCustomer["PostalCode"].value 
      oCGI.cOutString +=  [</td>] 

      // we are done with this row, add the end TR tag:
      oCGI.cOutString +=  [</tr>] 

      // move to next row in table (bad idea to leave this out!):
      rCustomer.next()

   enddo

   // close off the table:
   oCGI.cOutString +=  [</table></center>] 


   // done with the data ...
   // add an anchor tag to go back to the main application menu
   oCGI.cOutString +=  [<p><hr><p>] 
   oCGI.cOutString +=  [<a href="../index.htm">Main Application Menu</a>] 

   // Stream out cOutString:
   oCGI.streamDetail( oCGI.cOutString )

   // ---------------------------------------------------
   // stream out the footer:
   oCGI.streamFooter()

   // we're done. While not absolutely necessary, this can't
   // hurt:
   quit

catch( Exception E )

   oCGI.errorPage( e )

endtry
// --------------------------------------------------------------------
// End of program: DisplayCustomers.prg
// --------------------------------------------------------------------
